#!/bin/sh
# Fix swimlane files (swimfix.sh)
# jho 5 November 2007

# This fixes some problematic code in freshly-generated swimlane files.
#   1. In "vml_*.htm" files, replaces all instances of 'href="#"' with 
#      'style="cursor:pointer"'.
#   2. In all "*.htm" files, replaces all instances of "%5C" with "/".

# HOW YOU USE IT:
# 1. From the command line, navigate to the directory containing your swimlane files.
#    For example,
#    Windows: cd \Vasont\Extract\swimlane
#    Linux: cd /Vasont/Extract/swimlane

# 2. Run the script by entering the file path to the script.
#    For example,
#    Windows: \\filer1\docs\tools\batch\swimfix.sh
#    Linux: /pcc/docs/tools/batch/swimfix.sh

# LIMITATIONS:
# 1. This script only modifies files in the current directory. It does not modify files in
#    any subdirectories.
# 2. If you are running this script from Windows, you must have the MKS Toolkit installed 
#    to run shell scripts such as this one.

for filename in vml_*.htm
do
  sed 's|href=\"\#\"|style=\"cursor\:pointer\;\"|g' <$filename >$filename.new
  mv $filename.new $filename
done

for filename in *.htm
do
  sed 's|\%5C|\/|g' <$filename >$filename.new
  mv $filename.new $filename
done